Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| PGL DISTRIBUICAO DE ALIMENTOS LTDA
CNPJ: 87.397.865/0021-65 Inscrição Estadual: 1090357122
Evandro Behr - RS 509 KM 08, 6645, CAMOBI, Santa Maria, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 94773 Série: 209 Data de Emissão: 29/10/2019 20:16:48
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 1087 3978 6500 2165 6520 9000 0947 7310 0052 8520
Protocolo de Autorização: 143191489993313
CONSUMIDOR
Consumidor não identificado
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
434590 | PADARIA - PAO FRANCES PERUZZO KG | 0,457 | KG | 7,69 | 3,51
128190 | MASSA ROMENA PIZZA PZ 150G | 1 | UN | 3,99 | 3,99
128190 | MASSA ROMENA PIZZA PZ 150G | 1 | UN | 3,99 | 3,99
Valor total R$ | 11,49
Valor descontos R$ | 0,00
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:48